KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 115 variants A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Tab, Enter, Escape, Backtick, Backspace, Comma, Period, LeftBracket, RightBracket, Slash, LeftShift, RightShift, Num0, Num1, Num2, Num3, Num4, Num5, Num6, Num7, Num8, Num9, Space, Up, Down, Left, Right, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14, F15, F16, F17, F18, F19, F20, F21, F22, F23, F24, Semicolon, Apostrophe, Backslash, Minus, Equals, LeftCtrl, RightCtrl, LeftAlt, RightAlt, LeftSuper, RightSuper, CapsLock, Delete, Insert, Home, End, PageUp, PageDown, Numpad0, Numpad1, Numpad2, Numpad3, Numpad4, Numpad5, Numpad6, Numpad7, Numpad8, Numpad9, NumpadAdd, NumpadSubtract, NumpadMultiply, NumpadDivide, NumpadDecimal, NumpadEnter, NumLock, PrintScreen, Pause, ScrollLock,
}
Keyboard key codes

Variants



A

Letter key A.



B

Letter key B.



C

Letter key C.



D

Letter key D.



E

Letter key E.



F

Letter key F.



G

Letter key G.



H

Letter key H.



I

Letter key I.



J

Letter key J.



K

Letter key K.



L

Letter key L.



M

Letter key M.



N

Letter key N.



O

Letter key O.



P

Letter key P.



Q

Letter key Q.



R

Letter key R.



S

Letter key S.



T

Letter key T.



U

Letter key U.



V

Letter key V.



W

Letter key W.



X

Letter key X.



Y

Letter key Y.



Z

Letter key Z.



Tab

Tab key.



Enter

Enter/Return key.



Escape

Escape key.



Backtick

Backtick/grave-accent key.



Backspace

Backspace key.



Comma

Comma key.



Period

Period/full-stop key.



LeftBracket

Left square bracket [ key.



RightBracket

Right square bracket ] key.



Slash

Forward-slash / key.



LeftShift

Left Shift key.



RightShift

Right Shift key.



Num0

Digit row 0.



Num1

Digit row 1.



Num2

Digit row 2.



Num3

Digit row 3.



Num4

Digit row 4.



Num5

Digit row 5.



Num6

Digit row 6.



Num7

Digit row 7.



Num8

Digit row 8.



Num9

Digit row 9.



Space

Space bar.



Up

Arrow up.



Down

Arrow down.



Left

Arrow left.



Right

Arrow right.



F1

F1 function key.



F2

F2 function key.



F3

F3 function key.



F4

F4 function key.



F5

F5 function key.



F6

F6 function key.



F7

F7 function key.



F8

F8 function key.



F9

F9 function key.



F10

F10 function key.



F11

F11 function key.



F12

F12 function key.



F13

F13 function key.



F14

F14 function key.



F15

F15 function key.



F16

F16 function key.



F17

F17 function key.



F18

F18 function key.



F19

F19 function key.



F20

F20 function key.



F21

F21 function key.



F22

F22 function key.



F23

F23 function key.



F24

F24 function key.



Semicolon

Semicolon ;.



Apostrophe

Apostrophe '.



Backslash

Backslash \.



Minus

Minus -.



Equals

Equals =.



LeftCtrl

Left Ctrl key.



RightCtrl

Right Ctrl key.



LeftAlt

Left Alt key.



RightAlt

Right Alt key.



LeftSuper

Left Super (Windows/Command) key.



RightSuper

Right Super (Windows/Command) key.



CapsLock

Caps Lock key.



Delete

Delete key.



Insert

Insert key.



Home

Home key.



End

End key.



PageUp

Page Up key.



PageDown

Page Down key.



Numpad0

Numpad 0.



Numpad1

Numpad 1.



Numpad2

Numpad 2.



Numpad3

Numpad 3.



Numpad4

Numpad 4.



Numpad5

Numpad 5.



Numpad6

Numpad 6.



Numpad7

Numpad 7.



Numpad8

Numpad 8.



Numpad9

Numpad 9.



NumpadAdd

Numpad +.



NumpadSubtract

Numpad -.



NumpadMultiply

Numpad *.



NumpadDivide

Numpad /.



NumpadDecimal

Numpad . (decimal point).



NumpadEnter

Numpad Enter.



NumLock

Num Lock key.



PrintScreen

Print Screen key.



Pause

Pause/Break key.



ScrollLock

Scroll Lock key.