Module disk

Module disk 

Disk widget: a bounded circular plane with center, normal, and radius handles.

Structs

DiskWidget
An interactive disk widget: a bounded circular plane with center, normal, and radius.