#[non_exhaustive]pub enum DebugOutputMode {
Replace,
TintOverlay,
SplitScreen,
}Expand description
How the debug channel value is composited over the normal render.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Replace
Fragment color is entirely replaced by the debug output.
TintOverlay
Debug output is blended over the normal color at 50% opacity.
SplitScreen
Left half shows normal render, right half shows debug quantity.
Split position is set by DebugVis::split_x.