#[non_exhaustive]pub enum LightKind {
Directional {
direction: [f32; 3],
},
Point {
position: [f32; 3],
range: f32,
},
Spot {
position: [f32; 3],
direction: [f32; 3],
range: f32,
inner_angle: f32,
outer_angle: f32,
},
}Expand description
Light source type.
Directional emits parallel rays from a fixed direction (infinite distance).
Point emits rays from a position with distance-based falloff.
Spot emits a cone of light with inner (full-intensity) and outer (cutoff) angles.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Directional
Infinitely distant light with parallel rays (e.g. the sun).
Fields
Point
Omnidirectional point light with distance falloff.
Fields
Spot
Cone-shaped spotlight.
Fields