pub enum VelocityDist {
Fixed([f32; 3]),
UniformBox {
min: [f32; 3],
max: [f32; 3],
},
UniformCone {
axis: [f32; 3],
half_angle: f32,
min_speed: f32,
max_speed: f32,
},
}Expand description
Distribution used to assign an initial velocity to a newly spawned particle.
Variants
Fixed([f32; 3])
Every particle gets the same velocity.
UniformBox
Velocity is sampled uniformly inside an axis-aligned box.
Fields
UniformCone
Velocity direction is sampled uniformly inside a cone around axis,
magnitude in [min_speed, max_speed].