#[non_exhaustive]pub struct PointCloudItem {
pub positions: Vec<[f32; 3]>,
pub colors: Vec<[f32; 4]>,
pub scalars: Vec<f32>,
pub scalar_range: Option<(f32, f32)>,
pub colormap_id: Option<ColormapId>,
pub point_size: f32,
pub default_color: [f32; 4],
pub model: [[f32; 4]; 4],
pub render_mode: PointRenderMode,
pub id: u64,
pub radii: Vec<f32>,
pub transparencies: Vec<f32>,
}Expand description
A point cloud item to render in the viewport.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.positions: Vec<[f32; 3]>World-space positions (one vec3 per point).
colors: Vec<[f32; 4]>Optional per-point RGBA colors in linear [0,1]. If empty, uses default_color.
scalars: Vec<f32>Optional per-point scalar values for LUT coloring. If non-empty, overrides colors.
scalar_range: Option<(f32, f32)>Scalar range for LUT mapping. None = auto from min/max of scalars.
colormap_id: Option<ColormapId>Colormap for scalar coloring. None = use default builtin (viridis).
point_size: f32Screen-space point size in pixels. Default: 4.0.
default_color: [f32; 4]Fallback color when neither colors nor scalars are provided.
model: [[f32; 4]; 4]World-space model matrix. Default: identity.
render_mode: PointRenderModeRender mode. Default: ScreenSpaceCircle.
id: u64Unique ID for picking. 0 = not pickable.
radii: Vec<f32>Optional per-point radii in pixels. If non-empty, overrides point_size for each point.
transparencies: Vec<f32>Optional per-point opacity values in [0, 1]. If non-empty, scales each point’s alpha.