#[non_exhaustive]pub struct RuntimeFrameContext {
pub dt: f32,
pub camera: Camera,
pub viewport_size: Vec2,
pub input: ActionFrame,
pub pick_hit: Option<PickHit>,
pub clicked: bool,
pub drag_started: bool,
pub dragging: bool,
pub pointer_delta: Vec2,
pub cursor_viewport: Option<Vec2>,
pub shift_held: bool,
}Expand description
Per-frame inputs to super::ViewportRuntime::step.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dt: f32Wall-clock delta time in seconds since the last frame.
camera: CameraCurrent camera state.
viewport_size: Vec2Viewport dimensions in logical pixels.
input: ActionFrameResolved input actions for this frame.
pick_hit: Option<PickHit>Pick result under the cursor for this frame. Supply from CPU or GPU picking. None if no picking was done or nothing was hit.
clicked: boolTrue on the frame the primary pointer button was clicked (pressed and released without drag).
drag_started: boolTrue on the frame a primary drag began.
dragging: boolTrue while a primary drag is ongoing.
pointer_delta: Vec2Pointer movement in viewport pixels since last frame.
cursor_viewport: Option<Vec2>Cursor position in viewport-local pixels. None when outside the viewport.
shift_held: boolTrue when the shift modifier is held (for shift-click multi-select).