pub enum RuntimeEvent {
NodeAdded(NodeId),
NodeRemoved(NodeId),
}Expand description
An event emitted by the runtime when the scene node set changes.
Variants
NodeAdded(NodeId)
A node was added to the scene since the last frame.
NodeRemoved(NodeId)
A node was removed from the scene since the last frame.