#[non_exhaustive]pub enum ViewportError {
EmptyMesh {
positions: usize,
indices: usize,
},
MeshLengthMismatch {
positions: usize,
normals: usize,
},
MeshIndexOutOfBounds {
index: usize,
count: usize,
},
InvalidVertexIndex {
vertex_index: u32,
vertex_count: usize,
},
InvalidTextureData {
expected: usize,
actual: usize,
},
MeshSlotEmpty {
index: usize,
},
AttributeNotFound {
mesh_id: usize,
name: String,
},
AttributeLengthMismatch {
expected: usize,
got: usize,
},
}Expand description
Errors that can occur during mesh upload and manipulation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyMesh
Mesh data has empty positions or indices.
MeshLengthMismatch
Positions and normals arrays have different lengths.
MeshIndexOutOfBounds
Mesh index is out of bounds for the mesh storage.
InvalidVertexIndex
An index buffer entry references a vertex that does not exist.
InvalidTextureData
Texture RGBA data has an unexpected size.
Fields
MeshSlotEmpty
Attempted to access or replace a mesh slot that is empty (previously removed).
AttributeNotFound
Named scalar attribute not found on the given mesh.
Fields
AttributeLengthMismatch
Attribute data length does not match the existing buffer.
replace_attribute requires the same vertex count as the original upload.