#[non_exhaustive]pub struct VolumeMeshData {
pub positions: Vec<[f32; 3]>,
pub cells: Vec<[u32; 8]>,
pub cell_scalars: HashMap<String, Vec<f32>>,
pub cell_colors: HashMap<String, Vec<[f32; 4]>>,
}Expand description
Input data for an unstructured volume mesh (tets, hexes, or mixed).
Each cell is represented as exactly 8 vertex indices. For tetrahedral
cells, fill the last four indices with TET_SENTINEL (u32::MAX).
use viewport_lib::{VolumeMeshData, TET_SENTINEL};
// Two tets sharing vertices 0-1-2
let data = VolumeMeshData {
positions: vec![
[0.0, 0.0, 0.0],
[1.0, 0.0, 0.0],
[0.5, 1.0, 0.0],
[0.5, 0.5, 1.0],
[0.5, 0.5, -1.0],
],
cells: vec![
[0, 1, 2, 3, TET_SENTINEL, TET_SENTINEL, TET_SENTINEL, TET_SENTINEL],
[0, 2, 1, 4, TET_SENTINEL, TET_SENTINEL, TET_SENTINEL, TET_SENTINEL],
],
..Default::default()
};Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.positions: Vec<[f32; 3]>Vertex positions in local space.
cells: Vec<[u32; 8]>Cell connectivity : exactly 8 indices per cell.
Tets: first 4 indices are the tet vertices; indices [4..8] must be
TET_SENTINEL. Hexes: all 8 indices are valid.
cell_scalars: HashMap<String, Vec<f32>>Named per-cell scalar attributes (one f32 per cell).
Automatically remapped to boundary face scalars during upload so they
can be visualised via AttributeKind::Face.
cell_colors: HashMap<String, Vec<[f32; 4]>>Named per-cell RGBA color attributes (one [f32; 4] per cell).
Automatically remapped to boundary face colors during upload, rendered
via AttributeKind::FaceColor.